function pinit(varargin)
%PINIT  Initialize the Polynomial Toolbox
%
% PINIT must be called at the beginning of every Polynomial 
% Toolbox session to set the global variable structure PGLOBAL
% to its default values

%       Author(s):  S. Pejchova, M. Sebek 3-3-98
%       Copyright (c) 1998 by Polyx, Ltd.
%       $Revision: 2.0 $  $Date: 30-Apr-1999 11:46:50   $
%       $Revision: 2.5 $  $Date: 26-Oct-2000  S.Pejchova  $
%                      $  $Date: 21-Feb-2001 S. Pejchova  $
%                      $  $date: 14-Mar-2002 Z.Hurak $

pli_str=which('plic.mat');
if isempty(pli_str),error('Polynomial Toolbox file plic.mat does not exist.'); end;

try,
    load(pli_str),
catch,
    L_str='';
    L_num=[]; 
end

if (~exist('L_str','var')==1)|(~exist('L_num','var')), L_str=''; L_num=[]; end;
if isempty(L_num) | ~sum(L_num) | mod(sum(L_num),7),
   plicense('Init',varargin{1:nargin});
else,
   clear global PGLOBAL*;
   global PGLOBAL PGLOBAL1_ORDER;

   % Default values

   PGLOBAL.ZEROING = 1e-8;    % relative tolerance used for zeroing
   PGLOBAL.VERBOSE = 'no';    % flag to display extra comments during execution
   PGLOBAL.FORMAT = 'symbs';  % display format
   PGLOBAL.VARIABLE = 's';    % variable string
   PGLOBAL1_ORDER = 'normal'; % display format order

   % New values
   na = nargin; test1 = 0;
   for ii=1:na,
      argm=varargin{ii};
      switch argm,
       case {'s','p','z^-1','d','z','q'}
          PGLOBAL.VARIABLE = argm;
       case 'zi'
          PGLOBAL.VARIABLE = 'z^-1';
       case {'symb', 'coef', 'rcoef', 'block','symbs','symbr','rootr','rootc'}
          PGLOBAL.FORMAT = argm;
       case {'no', 'yes'}
          PGLOBAL.VERBOSE = argm;
       otherwise
          if isstr(argm) & ~isempty(argm),
             eval(['argm=',argm,';'],'test1=1;');
          end;
          if (isa(argm,'double')) & (all(size(argm)==1)),
             PGLOBAL.ZEROING = argm;
          else,
             test1=1;
          end; 
          if test1,
             error('Invalid input for global variable.');
          end;
      end;
   end;
   warning on;
 %  disp(' ');
 %  disp('  Polynomial Toolbox initialized. To get started, type one of'); 
 %  disp('  these: helpwin  or poldesk.  For product information, visit');
 %  disp('  www.polyx.com  or  www.polyx.cz.');
 %  disp(' ');
end;

% end .. pinit


